@@ -94,7 +94,7 @@ def sjoin(
     4        27         CHATHAM  MULTIPOINT ((-87.62715 41.73623))
     [5 rows x 95 columns]
 
-    See also
+    See Also
     --------
     overlay : overlay operation resulting in a new geometry
     GeoDataFrame.sjoin : equivalent method
@@ -140,14 +140,14 @@ def _maybe_make_list(obj):
 
 
 def _basic_checks(left_df, right_df, how, lsuffix, rsuffix, on_attribute=None):
-    """Checks the validity of join input parameters.
+    """Check the validity of join input parameters.
 
     `how` must be one of the valid options.
     `'index_'` concatenated with `lsuffix` or `rsuffix` must not already
     exist as columns in the left or right data frames.
 
     Parameters
-    ------------
+    ----------
     left_df : GeoDataFrame
     right_df : GeoData Frame
     how : str, one of 'left', 'right', 'inner'
@@ -212,7 +212,6 @@ def _geom_predicate_query(left_df, right_df, predicate, distance, on_attribute=N
         DataFrame with matching indices in
         columns named `_key_left` and `_key_right`.
     """
-
     original_predicate = predicate
 
     if predicate == "within":
@@ -346,7 +345,7 @@ def _process_column_names_with_suffix(
 
 def _restore_index(joined, index_names, index_names_original):
     """
-    Set back the the original index columns, and restoring their name as `None`
+    Set back the original index columns, and restoring their name as `None`
     if they didn't have a name originally.
     """
     if PANDAS_GE_30:
@@ -364,7 +363,8 @@ def _restore_index(joined, index_names, index_names_original):
 
 
 def _adjust_indexers(indices, distances, original_length, how, predicate):
-    """
+    """Adjust the indexers for the join based on the `how` parameter.
+
     The left/right indexers from the query represents an inner join.
     For a left or right join, we need to adjust them to include the rows
     that would not be present in an inner join.
@@ -426,7 +426,7 @@ def _frame_join(
         indices representing the matches from `left_df` and `right_df`
         respectively.
     distances : ndarray, optional
-        Passed trough and adapted based on the indices, if needed.
+        Passed through and adapted based on the indices, if needed.
     how : string
         The type of join to use on the DataFrame level.
     lsuffix : string
@@ -556,10 +556,10 @@ def _nearest_query(
 
 
 def _filter_shared_attribute(left_df, right_df, l_idx, r_idx, attribute):
-    """
-    Returns the indices for the left and right dataframe that share the same entry
-    in the attribute column. Also returns a Boolean `shared_attribute_rows` for rows
-    with the same entry.
+    """Return the indices for the left and right dataframe that share the same entry
+    in the attribute column.
+
+    Also returns a Boolean `shared_attribute_rows` for rows with the same entry.
     """
     shared_attribute_rows = (
         left_df[attribute].iloc[l_idx].values == right_df[attribute].iloc[r_idx].values
@@ -680,7 +680,7 @@ chicago_w_groceries[chicago_w_groceries["community"] == "UPTOWN"]
     30          TARGET    UPTOWN
     30       Mariano's    UPTOWN
 
-    See also
+    See Also
     --------
     sjoin : binary predicate joins
     GeoDataFrame.sjoin_nearest : equivalent method
@@ -693,7 +693,6 @@ chicago_w_groceries[chicago_w_groceries["community"] == "UPTOWN"]
     Every operation in GeoPandas is planar, i.e. the potential third
     dimension is not taken into account.
     """
-
     _basic_checks(left_df, right_df, how, lsuffix, rsuffix)
 
     left_df.geometry.values.check_geographic_crs(stacklevel=1)
